@@ -10,10 +10,10 @@ class Pururin(object):
     Methods
     -------
     get: function
-        Gets doujin from id
+        Get doujin from id
 
     get_random: function
-        Gets random doujin
+        Get random doujin
 
     search: function
         Searches doujin by tags / artist / character / parody or group
@@ -34,9 +34,9 @@ class Pururin(object):
         self.specs = {"api_key": self.api_key}
 
     async def get(self, book: int) -> str:
-        """Get doujin from id
+        """Get pururin doujin book from Id
 
-        path: https://pururin.to/gallery/61119
+        example: https://pururin.to/gallery/61119
 
         Parameters
         ----------
@@ -59,7 +59,7 @@ class Pururin(object):
         return better_object(data)
 
     async def search(self, query: str, page: int = 1, sort: str = "newest") -> str:
-        """Search doujin by tags / artist / character / parody or group
+        """Search pururin by tags / artist / character / parody or group
 
         Parameters
         ----------
@@ -105,7 +105,7 @@ class Pururin(object):
         return better_object(data)
 
     async def get_random(self) -> str:
-        """Gets random doujin on pururin
+        """Get pururin random doujin
 
         Returns
         -------
